@@ -1251,7 +1251,7 @@ create_prefs (void)
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
-    gtk_frame_set_label(GTK_FRAME(frame), "Right-click options");
+    gtk_frame_set_label(GTK_FRAME(frame), _("Right-click options"));
     
     frameVbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (frameVbox);
@@ -1850,6 +1850,9 @@ GBLtranslators =
 "- de (German) translation of Asunder version 2.0\n"
 "\n"
 "Stefan Beck\n"
+"- de (German) translation of Asunder version 3.0.1 \n"
+"\n"
+"Rogge\n"
 "- de (German) translation of Asunder version 2.9.7\n"
 "\n"
 "Mike Kranidis\n"
@@ -2046,7 +2049,7 @@ GBLtranslators =
 "- ur_PK (Urdu/Pakistan) translation of Asunder version 2.0\n"
 "\n"
 "Shixiong Tian\n"
-"- zh_CN (Simplified Chineese) translation of Asunder versions 2.3, 2.9.5\n"
+"- zh_CN (Simplified Chineese) translation of Asunder versions 2.3, 2.9.5, 3.0.2\n"
 "\n"
 "Jeff Bai\n"
 "- zh_CN (Simplified Chineese) translation of Asunder version 2.5\n"
